# Related Work

There are excellent (and more mature) alternatives in this space that you should consider:

## OpenCode

[OpenCode](https://opencode.ai/) is a general purpose LLM coding agent tool
that is well designed and support many different agents (not just Claude).
They invented their own agent logic and have a strong ecosystem.

<video src="https://opencode.ai/_build/assets/opencode-min-CiEsORKQ.mp4" autoplay loop muted playsinline></video>

## Toad

[Toad](https://github.com/batrachianai/toad) is a Textual TUI built around the
ACP protocol (supporting many different agents) made by [Will
McGugan](https://willmcgugan.github.io/) the creator of Textual.

It is far more shiny than Claude Chic.

<video src="https://github.com/user-attachments/assets/ced36f4b-db02-4d29-8a0a-14ec64b22881" autoplay loop muted playsinline></video>

## Conductor

[Conductor](https://conductor.build/) is a Mac App that also provides parallel agents, good design, and similar features as Claude Chic.

![Conductor Screenshot](https://www.conductor.build/_next/image?url=%2Fdark-screenshot-no-bg.png&w=3840&q=75)

## Claude Code

[Claude Code](https://github.com/anthropics/claude-code).  It works.  It's solid.  It's moving fast.  You love it already.

![Claude Code Gif](https://github.com/anthropics/claude-code/raw/main/demo.gif)
